# KVRocket | Pure Python Embedded Tiny KV Store

## Disclaimer
This project was designed for internal use on a personal project. It isn't designed to replace production grade KV stores. Use at your own risk.

